@@ -1,3 +1,4 @@
+from inspect import isclass, ismodule
 from functools import wraps
 
 from .strings import cut_prefix
@@ -7,18 +8,21 @@ __all__ = ['cached_property', 'monkey']
 
 
 def cached_property(func):
-    @property
-    @wraps(func)
-    def wrapper(self):
-        attname = '_' + func.__name__
-        if not hasattr(self, attname):
-            setattr(self, attname, func(self))
-        return getattr(self, attname)
-    return wrapper
+    cache_attname = '_' + func.__name__
+
+    def getter(self):
+        if not hasattr(self, cache_attname):
+            setattr(self, cache_attname, func(self))
+        return getattr(self, cache_attname)
+
+    def setter(self, value):
+        setattr(self, cache_attname, value)
+
+    return property(getter, setter)
 
 
 def monkey(cls):
-    assert isinstance(cls, type), "Attempting to monkey patch non-class"
+    assert isclass(cls) or ismodule(cls), "Attempting to monkey patch non-class and non-module"
 
     def decorator(value):
         func = getattr(value, 'fget', value) # Support properties
@@ -30,3 +34,6 @@ def monkey(cls):
         setattr(cls, name, value)
         return value
     return decorator
+
+
+# TODO: monkey_mix()?
